@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -34,8 +35,6 @@
 #include <IOKit/IOWorkLoop.h>
 #include <IOKit/IOCommand.h>
 
-#define kDefaultRetries 3
-
 #pragma mark -
 
 OSDefineMetaClassAndStructors(IOFWAsyncStreamCommand, IOFWCommand)
@@ -62,28 +61,44 @@ bool IOFWAsyncStreamCommand::initAll(
                                 FWAsyncStreamCallback 	completion,
                                 void 					* refcon)
 {
-    if(!IOFWCommand::initWithController(control))
-        return false;
-    fMaxRetries = kDefaultRetries;
-    fCurRetries = fMaxRetries;
-    fMemDesc = hostMem;
-    fComplete = completion;
-    fSync = completion == NULL;
-    fRefCon = refcon;
-    fTimeout = 1000*125;	// 1000 frames, 125mSec
-    if(hostMem)
-        fSize = hostMem->getLength();
+	bool success = true;
+	
+	success = IOFWCommand::initWithController(control);
+	
+	if( success )
+	{
+		fMaxRetries = kFWCmdDefaultRetries;
+		fCurRetries = fMaxRetries;
+		fMemDesc = hostMem;
+		fComplete = completion;
+		fSync = completion == NULL;
+		fRefCon = refcon;
+		fTimeout = 1000*125;	// 1000 frames, 125mSec
+		if(hostMem)
+			fSize = hostMem->getLength();
 
-    fGeneration = generation;
-    fChannel = channel;
-    fSyncBits = sync;
-    fTag = tag;
-    fSpeed = speed;
-    fSize = size;
-    fFailOnReset = false;
-    return true;
+		fGeneration = generation;
+		fChannel = channel;
+		fSyncBits = sync;
+		fTag = tag;
+		fSpeed = speed;
+		fSize = size;
+		fFailOnReset = false;
+    }
+
+	return success;
 }
 
+// free
+//
+//
+
+void IOFWAsyncStreamCommand::free()
+{	
+	IOFWCommand::free();
+}
+
+
 // reinit
 //
 //
@@ -125,25 +140,45 @@ IOReturn IOFWAsyncStreamCommand::reinit(
 
 IOReturn IOFWAsyncStreamCommand::complete(IOReturn status)
 {
+	// latch the most recent completion status
+	IOFWCommand::fMembers->fCompletionStatus = status; 
+	
+	if( fStatus == kIOFireWireCompleting )
+	{
+		// prevent double completion
+		return kIOReturnSuccess;
+	}
+	
+	// tell the fwim we're completing
+	// this could cause this routine to be reentered, hence the protection above
+	
+	fStatus = kIOFireWireCompleting;
+	fControl->handleAsyncCompletion( this, status );
+	
+	// we're back - actually complete the command
+	IOReturn completion_status = IOFWCommand::fMembers->fCompletionStatus;
+
     removeFromQ();	// Remove from current queue
 
     // If we're in the middle of processing a bus reset and
     // the command should be retried after a bus reset, put it on the
     // 'after reset queue'
     // If we aren't still scanning the bus, and we're supposed to retry after bus resets, turn it into device offline 
-    if((status == kIOFireWireBusReset) && !fFailOnReset) {
-        if(fControl->scanningBus()) {
+    if( (completion_status == kIOFireWireBusReset) && !fFailOnReset) 
+	{
+        if(fControl->scanningBus()) 
+		{
             setHead(fControl->getAfterResetHandledQ());
             return fStatus = kIOFireWirePending;	// On a queue waiting to execute
         }
     }
-    fStatus = status;
+    fStatus = completion_status;
     if(fSync)
-        fSyncWakeup->signal(status);
+        fSyncWakeup->signal(completion_status);
     else if(fComplete)
-		(*fComplete)(fRefCon, status, fControl, this);
+		(*fComplete)(fRefCon, completion_status, fControl, this);
 
-    return status;
+    return completion_status;
 }
 
 // gotAck
