@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -58,10 +59,43 @@ OSMetaClassDefineReservedUnused(IOFWCommand, 1);
 
 bool IOFWCommand::initWithController(IOFireWireController *control)
 {
-    if(!IOCommand::init())
-        return false;
-    fControl = control;
-    return true;
+	bool success = true;
+	
+	success = IOCommand::init();
+	
+	if( success )
+	{
+		fControl = control;
+		fMembers = (IOFWCommand::MemberVariables*)IOMalloc( sizeof(MemberVariables) );
+		if( fMembers == NULL )
+			success = false;
+	}
+	
+	// zero member variables
+	
+	if( success )
+	{
+		bzero( fMembers, sizeof(MemberVariables) );
+	}
+	
+	return success;
+}
+
+// free
+//
+//
+
+void IOFWCommand::free()
+{	
+	if( fMembers != NULL )
+	{		
+		// free member variables
+		
+		IOFree( fMembers, sizeof(MemberVariables) );
+		fMembers = NULL;
+	}
+	
+	IOCommand::free();
 }
 
 // submit
@@ -373,15 +407,15 @@ void IOFWCommand::updateTimer()
                 {
                     AbsoluteTime now, dead;
                     clock_get_uptime(&now);
-                    IOLog("%s: insertAfter %s, time is %lx:%lx\n",
-                        getMetaClass()->getClassName(), prev->getMetaClass()->getClassName(), now.hi, now.lo);
+                    IOLog("%s: insertAfter %s, time is %llx\n",
+                        getMetaClass()->getClassName(), prev->getMetaClass()->getClassName(), AbsoluteTime_to_scalar(&now) );
                     {
                         IOFWCommand *t = timeoutQ.fHead;
                         while(t) 
 						{
                             AbsoluteTime d = t->getDeadline();
-                            IOLog("%s:%p deadline %lx:%lx\n",
-                                t->getMetaClass()->getClassName(), t, d.hi, d.lo);
+                            IOLog("%s:%p deadline %llx\n",
+                                t->getMetaClass()->getClassName(), t, AbsoluteTime_to_scalar(&d) );
                             t = t->getNext();
                         }
                     }
