@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -41,10 +42,7 @@ class IODCLProgram : public OSObject
 {
     OSDeclareAbstractStructors(IODCLProgram)
 
-	friend class IOFWUserLocalIsochPort ;
-	friend class IOFWLocalIsochPort ;
-	
-	protected:
+	private :	
 	
 		void * 						reserved0 ;//fDCLTaskToKernel;
 		void * 						reserved1 ;//fDataTaskToKernel;
@@ -52,6 +50,8 @@ class IODCLProgram : public OSObject
 		void *		 				reserved3 ;//		IOMemoryDescriptor *		fDCLDesc;
 		IOMemoryMap *				fBufferMem ;
 		void *		 				reserved5 ;//		IOMemoryCursor *			fDataCursor;
+
+	protected:
 	
 	/*! @struct ExpansionData
 		@discussion This structure will be used to expand the capablilties of the class in the future.
@@ -111,22 +111,19 @@ class IODCLProgram : public OSObject
 	
 		IOMemoryMap *			getBufferMap() const ;
 
-	protected :
+	public :
 	
 		// close/open isoch workloop gate...
 		// clients should not need to call these.
-		// (internal use only)
-		virtual void			closeGate() ;
-		virtual void			openGate() ;
+		virtual void			closeGate() = 0 ;
+		virtual void			openGate() = 0 ;
 
-		// call to synchronize with hardware/check for completed DCLs
-		// (internal use only)
-		virtual IOReturn		synchronizeWithIO() ;
+		virtual IOReturn		synchronizeWithIO() = 0 ;
 		
 	private:
 	
 		OSMetaClassDeclareReservedUsed(IODCLProgram, 0);
-		OSMetaClassDeclareReservedUnused(IODCLProgram, 1);
+		OSMetaClassDeclareReservedUsed(IODCLProgram, 1);
 		OSMetaClassDeclareReservedUnused(IODCLProgram, 2);
 		OSMetaClassDeclareReservedUnused(IODCLProgram, 3);
 		OSMetaClassDeclareReservedUnused(IODCLProgram, 4);
