@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -82,8 +83,8 @@ void IOFireWireController::timeoutQ::headChanged(IOFWCommand *oldHead)
             
         while(t) {
             AbsoluteTime d = t->getDeadline();
-            IOLog("%s:%p deadline %lx:%lx\n",
-                t->getMetaClass()->getClassName(), t, d.hi, d.lo);
+            IOLog("%s:%p deadline %llx\n",
+                t->getMetaClass()->getClassName(), t, AbsoluteTime_to_scalar(&d));
             t = t->getNext();
         }
     }
@@ -171,13 +172,13 @@ void IOFireWireController::processTimeout(IOTimerEventSource *src)
         clock_get_uptime(&now);
 
 #if 0
-        IOLog("processTimeout, time is %lx:%lx\n", now.hi, now.lo);
+        IOLog("processTimeout, time is %llx\n", AbsoluteTime_to_scalar(&now));
         {
             IOFWCommand *t = fTimeoutQ.fHead;
             while(t) {
                 AbsoluteTime d = t->getDeadline();
                 IOLog("%s:%p deadline %lx:%lx\n",
-                    t->getMetaClass()->getClassName(), t, d.hi, d.lo);
+                    t->getMetaClass()->getClassName(), t, AbsoluteTime_to_scalar(&d));
                 t = t->getNext();
             }
         }
@@ -187,7 +188,7 @@ void IOFireWireController::processTimeout(IOTimerEventSource *src)
             break;	// Command with earliest deadline is OK.
 
         // Make sure there isn't a packet waiting.
-        fFWIM->handleInterrupts(1);
+        fFWIM->handleInterrupts( NULL, 1 );
 		fFWIM->flushWaitingPackets();
 
         // Which may have changed the queue - see if earliest deadline has changed.
@@ -207,8 +208,8 @@ void IOFireWireController::processTimeout(IOTimerEventSource *src)
         src->wakeAtTime(fTimeoutQ.fHead->getDeadline());
         //AbsoluteTime now;
         //clock_get_uptime(&now);
-        //IOLog("processTimeout, timeoutQ waketime %lx:%lx (now %lx:%lx)\n",
-        //        fTimeoutQ.fHead->getDeadline().hi, fTimeoutQ.fHead->getDeadline().lo, now.hi, now.lo);
+        //IOLog("processTimeout, timeoutQ waketime %lx:%lx (now %llx)\n",
+        //        fTimeoutQ.fHead->getDeadline().hi, fTimeoutQ.fHead->getDeadline().lo, AbsoluteTime_to_scalar(&now));
     }
     else 
 	{
