@@ -3,19 +3,20 @@
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
-* The contents of this file constitute Original Code as defined in and
-* are subject to the Apple Public Source License Version 1.1 (the
-* "License").  You may not use this file except in compliance with the
-* License.  Please obtain a copy of the License at
-* http://www.apple.com/publicsource and read it before using this file.
+* This file contains Original Code and/or Modifications of Original Code
+* as defined in and that are subject to the Apple Public Source License
+* Version 2.0 (the 'License'). You may not use this file except in
+* compliance with the License. Please obtain a copy of the License at
+* http://www.opensource.apple.com/apsl/ and read it before using this
+* file.
 * 
-* This Original Code and all software distributed under the License are
-* distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+* The Original Code and all software distributed under the License are
+* distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
-* License for the specific language governing rights and limitations
-* under the License.
+* FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+* Please see the License for the specific language governing rights and
+* limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
@@ -63,9 +64,9 @@ extern bool findOffsetInRanges ( IOVirtualAddress address, unsigned rangeCount,
 
 static bool
 getDCLDataBuffer(
-		const DCLCommand *			dcl,
-		IOVirtualAddress &			outDataBuffer,
-		IOByteCount &				outDataLength )
+	const DCLCommand *			dcl,
+	IOVirtualAddress &			outDataBuffer,
+	IOByteCount &				outDataLength )
 {
 	Boolean	result = false ;
 
@@ -259,8 +260,10 @@ IOFWUserLocalIsochPort :: free()
 	fProgramBuffer = NULL ;
 
 	if ( fLock )
+	{
 		IORecursiveLockFree( fLock ) ;
-		
+	}
+	
 	delete[] fDCLTable ;
 	fDCLTable = NULL ;
 	
@@ -288,7 +291,7 @@ IOFWUserLocalIsochPort :: initWithUserDCLProgram (
 		ErrorLog ( "Couldn't allocate recursive lock\n" ) ;
 		return false ;
 	}
-	
+
 // init easy params
 
 	fUserObj = params->userObj ;
@@ -296,9 +299,9 @@ IOFWUserLocalIsochPort :: initWithUserDCLProgram (
 	fDCLPool = NULL ;
 	fProgramCount = 0;
 	fStarted = false ;
-	
-	IOReturn error = kIOReturnSuccess ;
 
+	IOReturn error = kIOReturnSuccess ;
+	
 // get user program ranges:
 
 	IOVirtualRange * bufferRanges = new IOVirtualRange[ params->bufferRangeCount ] ;
@@ -435,7 +438,7 @@ IOFWUserLocalIsochPort :: initWithUserDCLProgram (
 				infoAux.u.v2.workloop = params->options & kFWIsochPortUseSeparateKernelThread ? createRealtimeThread() : NULL ;
 				infoAux.u.v2.options = params->options ;
 			}
-			
+						
 			IOFireWireBus::DCLTaskInfo info = { 0, 0, 0, 0, 0, 0, & infoAux } ;
 			
 			program = fUserClient->getOwner()->getController()->getLink()->createDCLProgram(	params->talking,
@@ -447,14 +450,14 @@ IOFWUserLocalIsochPort :: initWithUserDCLProgram (
 
 			bufferMap->release() ;		// retained by DCL program
 			bufferMap = NULL ;
-
+			
 			if (  infoAux.u.v2.workloop )
 			{
 				// If we created a custom workloop, it will be retained by the program...
 				// We can release our reference...
 				infoAux.u.v2.workloop->release() ;
 			}
-						
+			
 			DebugLogCond( !program, "createDCLProgram returned nil\n" ) ;
 		}
 
@@ -489,6 +492,7 @@ IOFWUserLocalIsochPort :: initWithUserDCLProgram (
 	return ( ! error ) ;
 }
 
+
 IOReturn
 IOFWUserLocalIsochPort :: importUserProgram (
 		IOMemoryDescriptor *		userExportDesc,
@@ -705,7 +709,14 @@ IOFWUserLocalIsochPort :: s_dclCallProcHandler( DCLCallProc * dcl )
 	
 	if ( dcl->procData )
 	{
+#if 0
+// DEBUG
+		DebugThing * debugThing = (DebugThing*)dcl->procData ;
+		IOFireWireUserClient::sendAsyncResult( (natural_t*)debugThing->asyncRef, kIOReturnSuccess, NULL, 0 ) ;
+		DebugLog("send callback port=%p\n", debugThing->port ) ;
+#else
 		IOFireWireUserClient::sendAsyncResult( (natural_t*)dcl->procData, kIOReturnSuccess, NULL, 0 ) ;
+#endif
 	}	
 }
 
