@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -35,8 +36,8 @@
 OSDefineMetaClassAndAbstractStructors(IOFireWireBusAux, OSObject);
 
 OSMetaClassDefineReservedUsed(IOFireWireBusAux, 0);			// createDCLPool
-OSMetaClassDefineReservedUnused(IOFireWireBusAux, 1);		// will be createBufferFillIsochPort
-OSMetaClassDefineReservedUnused(IOFireWireBusAux, 2);
+OSMetaClassDefineReservedUsed(IOFireWireBusAux, 1);			// createBufferFillIsochPort
+OSMetaClassDefineReservedUsed(IOFireWireBusAux, 2);			// getMaxRec
 OSMetaClassDefineReservedUnused(IOFireWireBusAux, 3);
 OSMetaClassDefineReservedUnused(IOFireWireBusAux, 4);
 OSMetaClassDefineReservedUnused(IOFireWireBusAux, 5);
@@ -81,3 +82,9 @@ OSDefineAbstractStructors(IOFireWireBus, IOService)
 //OSMetaClassDefineReservedUnused(IOFireWireBus, 5);
 //OSMetaClassDefineReservedUnused(IOFireWireBus, 6);
 //OSMetaClassDefineReservedUnused(IOFireWireBus, 7);
+
+IOFWBufferFillIsochPort *
+IOFireWireBus :: createBufferFillIsochPort()
+{
+	return fAuxiliary->createBufferFillIsochPort() ;
+}
