@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -70,9 +71,8 @@ bool IOFireWireDeviceAux::init( IOFireWireDevice * primary )
 	
 	if( success )
 	{
-		fTerminated = false;
-		fMaxSpeed = kFWSpeedMaximum;
 		fUnitCount = 0;
+		fMaxSpeed = kFWSpeedMaximum;
 	}
 	
 	return success;
@@ -84,16 +84,56 @@ bool IOFireWireDeviceAux::init( IOFireWireDevice * primary )
 
 bool IOFireWireDeviceAux::isTerminated( void )
 {
-	return (fTerminated || fPrimary->isInactive());
+	return ((fTerminationState == kTerminated) || fPrimary->isInactive());
 }
 
-// isTerminated
+// setTerminationState
 //
 //
 
-void IOFireWireDeviceAux::setTerminated( bool terminated )
+void IOFireWireDeviceAux::setTerminationState( TerminationState state )
 {
-	fTerminated = terminated;
+	IOReturn status = kIOReturnSuccess;
+	
+	IOFireWireNubAux::setTerminationState( state );
+	
+	if( fTerminationState == kTerminated )
+	{
+		// tell all the units that they have been terminated as well
+		
+		OSIterator * clientIterator = NULL;
+		OSObject * client = NULL;
+	
+		if( status == kIOReturnSuccess )
+		{
+			clientIterator = fPrimary->getClientIterator();
+			if( clientIterator == NULL )
+				status = kIOReturnError;
+		}
+		
+		if( status == kIOReturnSuccess )
+		{
+			clientIterator->reset();
+			
+			while( (client = clientIterator->getNextObject()) ) 
+			{
+				IOFireWireUnit * unit;
+				
+				unit = OSDynamicCast( IOFireWireUnit, client );
+				if( unit )
+				{
+					unit->setTerminationState( kTerminated );
+				}
+			}
+		}
+		
+		if( clientIterator != NULL )
+		{
+			clientIterator->release();
+		}
+	}
+	
+	FWKLOGASSERT( status == kIOReturnSuccess );
 }
 
 // setMaxSpeed
@@ -1223,6 +1263,7 @@ IOReturn IOFireWireDevice::processUnitDirectories( OSSet * unitSet )
 	if( status == kIOReturnSuccess )
 	{	
 		UInt32 count = unitSet->getCount();
+		//IOLog( "IOFireWireDevice::processUnitDirectories - unit_count = %ld\n", count );
 		setUnitCount( count );
 		
 		iterator = OSCollectionIterator::withCollection( unitSet );
@@ -1245,22 +1286,46 @@ IOReturn IOFireWireDevice::processUnitDirectories( OSSet * unitSet )
 				while( (client = clientIterator->getNextObject()) ) 
 				{
 					found = OSDynamicCast(IOFireWireUnit, client);
-					if( found && found->matchPropertyTable(propTable) ) 
+					if( found )
 					{
-						break;
-					}
-					else
-					{
-						found = NULL;
+						// sync with open close routines on unit
+						
+						found->lockForArbitration();  
+											
+						if( (found->getTerminationState() != kTerminated) && found->matchPropertyTable(propTable) ) 
+						{
+							// arbitration lock still held
+							
+							break;
+						}
+						else
+						{
+							found->unlockForArbitration();
+							
+							found = NULL;
+						}
+						
 					}
 				}
 				
 				if( found )
 				{
+					// arbitration lock still held
+					
+					if( found->getTerminationState() == kNeedsTermination )
+					{
+						found->setTerminationState( kNotTerminated );
+					}
+					
+					found->unlockForArbitration();
+										
 					found->setConfigDirectory( unit );
+
 					clientSet->removeObject( found );
+					
 					break;
 				}
+
 		
 				newDevice = new IOFireWireUnit;
 		
@@ -1291,6 +1356,30 @@ IOReturn IOFireWireDevice::processUnitDirectories( OSSet * unitSet )
 		iterator->release();
 	}
 	
+	//
+	// destroy any units that have disappeared
+	//
+	
+	if( status == kIOReturnSuccess )
+	{
+		clientIterator->reset();
+		while( (client = clientIterator->getNextObject()) ) 
+		{
+			IOFireWireUnit * unit;
+			
+			unit = OSDynamicCast(IOFireWireUnit, client);
+			
+			if( unit )
+			{
+				unit->terminateUnit();
+			}
+		}
+	}
+	
+	//
+	// cleanup
+	//
+	
 	if( clientIterator != NULL )
 	{
 		clientIterator->release();
@@ -1379,9 +1468,11 @@ IOReturn IOFireWireDevice::message( UInt32 mess, IOService * provider,
     return IOService::message(mess, provider, argument );
 }
 
-/**
- ** Open / Close methods
- **/
+ #pragma mark -
+
+/////////////////////////////////////////////////////////////////////////////
+// open / close
+//
  
  // we override these two methods to allow a reference counted open from
  // IOFireWireUnits only.  Exclusive access is enforced for non-Unit clients.
@@ -1392,6 +1483,8 @@ IOReturn IOFireWireDevice::message( UInt32 mess, IOService * provider,
  
 bool IOFireWireDevice::handleOpen( IOService * forClient, IOOptionBits options, void * arg )
 {
+	// arbitration lock is held
+
     bool ok = true;
     
     IOFireWireUnit * unitClient = OSDynamicCast( IOFireWireUnit, forClient );
@@ -1444,6 +1537,8 @@ bool IOFireWireDevice::handleOpen( IOService * forClient, IOOptionBits options,
 
 void IOFireWireDevice::handleClose( IOService * forClient, IOOptionBits options )
 {
+	// arbitration lock is held
+
     IOFireWireUnit * unitClient = OSDynamicCast( IOFireWireUnit, forClient );
     if( unitClient != NULL )
     {
@@ -1456,10 +1551,10 @@ void IOFireWireDevice::handleClose( IOService * forClient, IOOptionBits options
                 IOService::handleClose( this, options );
                 
                 // terminate if we're no longer on the bus and haven't already been terminated.
-                if( fNodeID == kFWBadNodeID && !isTerminated() ) 
+                if( getTerminationState() == kNeedsTermination ) 
 				{
-					setTerminated( true );
-                    IOCreateThread(terminateDevice, this);
+					setTerminationState( kTerminated );
+                    IOCreateThread( terminateDevice, this );
                 }
             }
         }
@@ -1472,9 +1567,9 @@ void IOFireWireDevice::handleClose( IOService * forClient, IOOptionBits options
             IOService::handleClose( forClient, options );
             
             // terminate if we're no longer on the bus
-            if( fNodeID == kFWBadNodeID && !isTerminated() )
+			if( getTerminationState() == kNeedsTermination ) 
 			{
-				setTerminated( true );
+				setTerminationState( kTerminated );
                 IOCreateThread(terminateDevice, this);
 			}
 		}
@@ -1487,6 +1582,8 @@ void IOFireWireDevice::handleClose( IOService * forClient, IOOptionBits options
 
 bool IOFireWireDevice::handleIsOpen( const IOService * forClient ) const
 {
+	// arbitration lock is held
+
     if( forClient == NULL )
     {
         return (fOpenFromUnitCount != 0 || fOpenFromDevice);
@@ -1610,7 +1707,6 @@ IOReturn IOFireWireDevice::configureNode( void )
 		
 		if( fNodeFlags & kIOFWDisablePhyOnSleep && (hopCount() == 1) )
 		{
-//			IOLog( "IOFireWireDevice::configureNode - kIOFWDisablePhyOnSleep %lx\n", fNodeID );
 			fControl->disablePhyPortOnSleepForNodeID( fNodeID & 0x3f );
 		}
 	}
