@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -51,9 +52,8 @@ class IOFireWireDeviceAux : public IOFireWireNubAux
 	
 protected:
 	
-	bool 		fTerminated;
-	IOFWSpeed	fMaxSpeed;
 	UInt32		fUnitCount;
+	IOFWSpeed	fMaxSpeed;
 	
 	/*! 
 		@struct ExpansionData
@@ -71,15 +71,14 @@ protected:
 
     virtual bool init( IOFireWireDevice * primary );
 	virtual	void free();
-	
-	virtual bool isTerminated( void );
-	virtual void setTerminated( bool terminated );
 
+	virtual bool isTerminated( void );
+	virtual void setTerminationState( TerminationState state );
 	void setMaxSpeed( IOFWSpeed speed );
 	
 	void setUnitCount( UInt32 count );
 	UInt32 getUnitCount( void );
-	
+		
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 0);
     OSMetaClassDeclareReservedUnused(IOFireWireDeviceAux, 1);
@@ -198,12 +197,7 @@ protected:
 public:
 	inline bool isTerminated( void )
 		{ return ((IOFireWireDeviceAux*)fAuxiliary)->isTerminated(); }
-
-protected:	
-	inline void setTerminated( bool terminated )
-		{ ((IOFireWireDeviceAux*)fAuxiliary)->setTerminated( terminated ); }
-
-public:
+		
 	inline void setMaxSpeed( IOFWSpeed speed )
 		{ ((IOFireWireDeviceAux*)fAuxiliary)->setMaxSpeed( speed ); }		
 
