@@ -3,8 +3,6 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -24,6 +22,7 @@
  */
  
 #include "IOFireWireMagicMatchingNub.h"
+#include <IOKit/firewire/IOFireWireFamilyCommon.h>
 
 OSDefineMetaClassAndStructors(IOFireWireMagicMatchingNub, IOService)
 
@@ -36,3 +35,36 @@ bool IOFireWireMagicMatchingNub::matchPropertyTable( OSDictionary * table )
         
     return clientClass->isEqualTo( getProperty( "IODesiredChild" ) );
 }
+
+// message
+//
+//
+
+IOReturn IOFireWireMagicMatchingNub::message( 	UInt32 		mess, 
+												IOService *	provider,
+												void * 		argument )
+{
+    // Propagate bus reset start/end messages
+    if( kIOMessageServiceIsResumed == mess ||
+        kIOMessageServiceIsSuspended == mess ||
+        kIOMessageServiceIsRequestingClose == mess ||
+        kIOFWMessageServiceIsRequestingClose == mess ) 
+	{
+ 		messageClients( mess );
+        return kIOReturnSuccess;
+    }
+	
+	if( kIOFWMessagePowerStateChanged == mess )
+	{
+		messageClients( mess );
+		return kIOReturnSuccess;
+	}
+
+	if( kIOFWMessageTopologyChanged == mess )
+	{
+		messageClients( mess );
+		return kIOReturnSuccess;
+	}
+	
+    return IOService::message(mess, provider, argument );
+}
\ No newline at end of file
