@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -40,6 +41,15 @@ class IOFireWireController;
 class IOFireWireBus;
 class IOConfigDirectory;
 class IOFireWireNub;
+class IOFireWireDevice;
+class IOFireWireUnit;
+
+enum TerminationState
+{
+	kNotTerminated = 0,
+	kNeedsTermination,
+	kTerminated
+};
 
 #pragma mark -
 
@@ -56,6 +66,7 @@ class IOFireWireNubAux : public OSObject
 protected:
 	
 	IOFireWireNub * 		fPrimary;
+	TerminationState		fTerminationState;
 	
 	/*! 
 		@struct ExpansionData
@@ -77,6 +88,9 @@ protected:
 	virtual UInt32 hopCount( IOFireWireNub * nub );
 	virtual UInt32 hopCount( void );
 	
+	virtual TerminationState getTerminationState( void );
+	virtual void setTerminationState( TerminationState state );
+	
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireNubAux, 0);
     OSMetaClassDeclareReservedUnused(IOFireWireNubAux, 1);
@@ -109,6 +123,8 @@ class IOFireWireNub : public IOService
     friend class IOFireWireNubAux;
 	friend class IOFireWireDeviceAux;
 	friend class IOFireWireUnitAux;
+	friend class IOFireWireDevice;
+	friend class IOFireWireUnit;
    
 /*------------------Useful info about device (also available in the registry)--------*/
 protected:
@@ -244,8 +260,14 @@ public:
 		
 	inline UInt32 hopCount( void )
 		{ return fAuxiliary->hopCount(); }
-		
+
+	inline TerminationState getTerminationState( void )
+		{ return fAuxiliary->getTerminationState(); }
+				
 protected:
+	inline void setTerminationState( TerminationState state )
+		{ fAuxiliary->setTerminationState( state ); }
+
 	virtual IOFireWireNubAux * createAuxiliary( void );
     
 private:
