@@ -2,21 +2,22 @@
 * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
-*
-* The contents of this file constitute Original Code as defined in and
-* are subject to the Apple Public Source License Version 1.1 (the
-* "License").  You may not use this file except in compliance with the
-* License.  Please obtain a copy of the License at
-* http://www.apple.com/publicsource and read it before using this file.
-*
-* This Original Code and all software distributed under the License are
-* distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+* 
+* This file contains Original Code and/or Modifications of Original Code
+* as defined in and that are subject to the Apple Public Source License
+* Version 2.0 (the 'License'). You may not use this file except in
+* compliance with the License. Please obtain a copy of the License at
+* http://www.opensource.apple.com/apsl/ and read it before using this
+* file.
+* 
+* The Original Code and all software distributed under the License are
+* distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
-* License for the specific language governing rights and limitations
-* under the License.
-*
+* FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+* Please see the License for the specific language governing rights and
+* limitations under the License.
+* 
 * @APPLE_LICENSE_HEADER_END@
 */
 
@@ -30,11 +31,14 @@
 
 class OSArray;
 class OSData;
+class IOFireWireController;
 
 /*! @class IOLocalConfigDirectory
 */
 class IOLocalConfigDirectory : public IOConfigDirectory
 {
+	friend class IOFireWireController;
+
 	OSDeclareDefaultStructors(IOLocalConfigDirectory);
 
 protected:
@@ -92,6 +96,8 @@ protected:
 
 	// call eats a retain count
 	virtual IOReturn addEntry(OSString *desc);
+
+	IOReturn incrementGeneration( void );
 		
 private:
 	OSMetaClassDeclareReservedUsed(IOLocalConfigDirectory, 0);
