@@ -6,6 +6,9 @@
  *  Copyright (c) 2003 Apple Computer, Inc. All rights reserved.
  *
  * $Log: prefix.h,v $
+ * Revision 1.3  2004/03/03 19:53:37  niels
+ * fix prefix header for native target building
+ *
  * Revision 1.2  2003/07/21 06:52:59  niels
  * merge isoch to TOT
  *
@@ -14,6 +17,8 @@
  *
  */
 
+#ifdef __cplusplus
+
 // system
 #import <IOKit/system.h>
 #import <IOKit/assert.h>
@@ -48,3 +53,5 @@
 #import <IOKit/firewire/IOFireWireFamilyCommon.h>
 
 #import <sys/proc.h>
+
+#endif
