@@ -3,8 +3,6 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -58,18 +56,18 @@ namespace IOFireWireLib {
 			virtual IOReturn			Start() ;
 			virtual IOReturn			Stop() ;
 					
-			virtual ForceStopHandler	SetChannelForceStopHandler( ForceStopHandler stopProc ) ;
+			virtual ForceStopHandler	SetChannelForceStopHandler( ForceStopHandler stopProc, IOFireWireLibIsochChannelRef interface ) ;
 			virtual void	 			SetRefCon( void* stopProcRefCon ) ;
 			virtual void*				GetRefCon() ;
 
 			virtual Boolean				NotificationIsOn() ;
-			virtual Boolean				TurnOnNotification() ;
+			virtual Boolean				TurnOnNotification( IOFireWireLibIsochChannelRef interface ) ;
 			virtual void				TurnOffNotification() ;
 
 			virtual void				ClientCommandIsComplete( FWClientCommandID commandID, IOReturn status ) ;
 		
 		protected:
-			static void					ForceStop( ChannelRef refcon, IOReturn result, void** args, int numArgs ) ;
+//			static void					ForceStop( ChannelRef refcon, IOReturn result, void** args, int numArgs ) ;
 		
 		protected:
 			Device&						mUserClient ;
