@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -227,7 +228,7 @@ namespace IOFireWireLib {
 			LocalIsochPort (	const IUnknownVTbl & interface, Device & userClient, bool talking, DCLCommand * dclProgram, 
 								UInt32 startEvent, UInt32 startState, UInt32 startMask, 
 								IOVirtualRange programRanges[], UInt32 programRangeCount, IOVirtualRange bufferRanges[], 
-								UInt32 bufferRangeCount ) ;								
+								UInt32 bufferRangeCount, IOFWIsochPortOptions options ) ;								
 			virtual ~LocalIsochPort () ;
 
 		protected :
@@ -282,7 +283,8 @@ namespace IOFireWireLib {
 		public:
 			LocalIsochPortCOM( Device& userclient, bool inTalking, DCLCommand* inDCLProgram, UInt32 inStartEvent,
 					UInt32 inStartState, UInt32 inStartMask, IOVirtualRange inDCLProgramRanges[], 
-					UInt32 inDCLProgramRangeCount, IOVirtualRange inBufferRanges[], UInt32 inBufferRangeCount) ;
+					UInt32 inDCLProgramRangeCount, IOVirtualRange inBufferRanges[], UInt32 inBufferRangeCount,
+					IOFWIsochPortOptions options ) ;
 			virtual ~LocalIsochPortCOM() ;	
 			
 			// --- IUNKNOWN support ----------------
@@ -296,7 +298,8 @@ namespace IOFireWireLib {
 											IOVirtualRange					inDCLProgramRanges[],			// optional optimization parameters
 											UInt32							inDCLProgramRangeCount,
 											IOVirtualRange					inBufferRanges[],
-											UInt32							inBufferRangeCount) ;
+											UInt32							inBufferRangeCount,
+											IOFWIsochPortOptions			options ) ;
 			virtual HRESULT			QueryInterface(
 											REFIID 		iid, 
 											void** 		ppv ) ;
